package com.sd.wln.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.sd.business.entity.sku.po.SkuClassify;
import com.sd.business.service.sku.SkuClassifyService;
import com.sd.wln.service.WlnSkuService;
import com.sd.wln.util.WlnUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

@Slf4j
@Service
public class WlnSkuServiceImpl implements WlnSkuService {

    @Autowired
    private SkuClassifyService skuClassifyService;

    @Override
    public boolean SyncSkuClassify() {

        int page = 1;
        int size;
        List<JSONObject> list = new ArrayList<>();

        // 查询万里牛sku分类
        do {
            try {
                List<JSONObject> skuClassifyList = WlnUtil.getSkuClassifyList(page, 50);
                list.addAll(skuClassifyList);
                size = skuClassifyList.size();
            } catch (Exception e) {
                log.error("sku分类同步错误", e);
                return false;
            }
        } while (size >= 50);

        // 查询数据库sku分类
        List<SkuClassify> mysqlSkuClassifyList = skuClassifyService.list();
        Map<String, SkuClassify> skuClassifyMap = mysqlSkuClassifyList.stream()
                .collect(Collectors.toMap(SkuClassify::getWlnCatagoryid, Function.identity()));

        // 去重合并
        List<SkuClassify> skuClassifyList = new ArrayList<>();
        for (int i = 0; i < list.size(); i++) {
            JSONObject item = list.get(i);
            String catagoryid = item.getString("catagoryid");

            SkuClassify skuClassify = skuClassifyMap.get(catagoryid);
            if (skuClassify == null) {
                skuClassify = new SkuClassify();
                skuClassify.setId(IdWorker.getId());
            }
            skuClassify.setName(item.getString("catagory_name"));
            skuClassify.setWlnCatagoryid(catagoryid);
            skuClassify.setWlnParentid(item.getString("parentid"));
            skuClassify.setSort(i);
            skuClassifyList.add(skuClassify);
        }

        // 赋值parentId
        Map<String, Long> map = skuClassifyList.stream()
                .collect(Collectors.toMap(SkuClassify::getWlnCatagoryid, SkuClassify::getId, (t1, t2) -> t1));
        for (SkuClassify skuClassify : skuClassifyList) {
            skuClassify.setParentId(map.getOrDefault(skuClassify.getWlnParentid(), 0L));
        }

        // 更新数据库
        skuClassifyService.saveOrUpdateBatch(skuClassifyList);
        return true;
    }

}
